
import __config from 'config/env';
import util from 'utils/util';

const request = (url, method, data, showLoading) => {
	let _url = url;
	_url =  __config.basePath + url
	return new Promise((resolve, reject) => {
		if (showLoading) {
			uni.showLoading({
				title: '加载中'
			});
		}
		uni.request({
			url: _url,
			method: method,
			data: data,
			withCredentials: true,
			header: {
				'Authorization': uni.getStorageSync('third_session') ? uni.getStorageSync('third_session') : '',
			},
			success(res) {
				if (res.data.code == 1) {
					resolve(res.data);
				}else if (res.statusCode == 404) {
					uni.showModal({
						title: '提示',
						content: '接口请求出错，请检查手机网络',
						success(res) {}
					});
					reject();
				} else if (res.statusCode == 502) {
					console.log(502)
					uni.showModal({
						title: '提示',
						content: '服务启维护中，请稍后再来',
						success(res) {}
					});
					reject();
				} else if (res.statusCode == 503) {
					console.log(503)
					uni.showModal({
						title: '提示',
						content: '503错误，服务未启动',
						success(res) {}
					});
					reject();
				}else {
					if(res.data.code==-1){
						console.error(12321)
						uni.navigateTo({
							url:"/pages/mandate/index"
						})
						return;
					}
					uni.showModal({
						title: '提示',
						content: '错误：'+res.data.msg,
						success(res) {}
					});
					reject();
				}
			},
			fail(error) {
				console.error(12321)
				uni.showModal({
					title: '提示',
					content: '接口请求出错：' + error.errMsg,
					success(res) {}
				});
				reject(error);
			},
			complete(res) {
				uni.hideLoading();
			}
		});
	});
};

module.exports = {
	request,
	weChatLogin: data => {
		//微信小程序登录接口
		return request('/api/Login/weChatLogin', 'post', data, false);
	},
	makeAppointment: data => {
		//创建预约
		return request('/api/Appointment/makeAppointment', 'post', data, false);
	},
	createOrder: data => {
		//创建订单
		return request('/api/Order/createOrder', 'post', data, false);
	},
	payOrder: data => {
		//订单支付
		return request('/api/Order/payOrder', 'post', data, false);
	},
	confirmReceipt: data => {
		//确认收货
		return request('/api/Order/confirmReceipt', 'post', data, false);
	},
	payOrders: data => {
		//洗鞋订单支付
		return request('/api/Wash_order/payOrder', 'post', data, false);
	},
	getUserInfo: data => {
		//获取个人信息
		return request('/api/User_center/getUserInfo', 'get', data, false);
	},
	getAddress: data => {
		//获取最近一次地址
		return request('/api/order/getAddress', 'get', data, false);
	},
	updateUserInfo: data => {
		//修改个人信息
		return request('/api/User_center/updateUserInfo', 'POST', data, false);
	},

	getGoodsCate: data => {
		//获取商品分类
		return request('/api/Mall/getGoodsCate', 'get', data, false);
	},
	getAppointmentList: data => {
		//获取预约列表
		return request('/api/Appointment/getAppointmentList', 'get', data, false);
	},
	getOrderList: data => {
		//获取商城订单列表
		return request('/api/Order/getOrderList', 'get', data, false);
	},
	createOrders: data => {
		//创建订单【创建洗鞋订】
		return request('/api/Wash_order/createOrder', 'POST', data, false);
	},
	getWashOrderList: data => {
		//获取订单列表
		return request('/api/Wash_order/getWashOrderList', 'get', data, false);
	},
	getWashOrderDetail: data => {
		//获取订单详情
		return request('/api/Wash_order/getWashOrderDetail', 'get', data, false);
	},
	cancelOrders: data => {
		//取消洗鞋订单
		return request('/api/Wash_order/cancelOrder', 'POST', data, false);
	},
	completeOrder: data => {
		//确认收货订单
		return request('/api/Wash_order/completeOrder', 'POST', data, false);
	},

	getOrderDetail: data => {
		//获取商品订单详情
		return request('/api/Order/getOrderDetail', 'get', data, false);
	},
	cancelOrder: data => {
		//取消订单商品订单
		return request('/api/Order/cancelOrder', 'post', data, false);
	},
	getAppointmentInfo: data => {
		//获取预约详情
		return request('/api/Appointment/getAppointmentInfo', 'get', data, false);
	},
	cancelAppointment: data => {
		//取消预约
		return request('/api/Appointment/cancelAppointment', 'POST', data, false);
	},
	completeAppointment: data => {
		//取消预约
		return request('/api/Appointment/completeAppointment', 'POST', data, false);
	},
	getWashCate: data => {
		//获取洗鞋分类
		return request('/api/Mall/getWashCate', 'get', data, false);
	},
	getGoodsList: data => {
		//获取商品列表
		return request('/api/Mall/getGoodsList', 'get', data, false);
	},
	getGoodsDetail: data => {
		//获取商品详情
		return request('/api/Mall/getGoodsDetail', 'get', data, false);
	},
	getAreaTree: data => {
		//获取地址列表
		return request('/api/area/getAreaTree', 'get', data, false);
	},
	getBanner: data => {
		//获取首页轮播图
		return request('/api/Expedite/getBanner', 'get', data, false);
	},
	getShopSet: data => {
		//获取店铺信息设置
		return request('/api/Expedite/getShopSet', 'get', data, false);
	},
	getSysConfig: data => {
		//获取平台文案设置
		return request('/api/Expedite/getSysConfig', 'get', data, false);
	},
};
